@@ -244,3 +244,20 @@ extern void sk_message(char outputprefs, int stdout_threshold, int log_threshold
         fclose(fid);
     }
 }
+
+
+/*
+ * Grab the warning and error messages from libxml validating the OMF file
+ * against the DTD and pass it to sk_message().
+ */
+void sk_dtd_validation_message(char *outputprefs, char *format, ...)
+{
+    va_list ap;
+    char message[4096];
+
+    va_start(ap, format);
+    vsprintf(message, format, ap);
+    va_end(ap);
+
+    sk_message(*outputprefs, SKOUT_VERBOSE, SKOUT_DEBUG, "(install)",_("OMF validation error: %s"), message);
+}
